==> snipe-it-7.0.11.zip: snipe-it-7.0.11/resources/lang/so-SO/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Ku saabsan Hantida',
    'about_assets_text'            => 'Hantidu waa shay lagu raadraaco lambar taxane ah ama sumad hanti ah. Waxay u muuqdaan inay yihiin shay qiimo sare leh marka la aqoonsanayo shay gaar ah.',
    'archived'  				=> 'Kaydsan',
    'asset'  					=> 'Hantida',
    'bulk_checkout'             => 'Hubinta Hantida',
    'bulk_checkin'              => 'Hubi Hantida',
    'checkin'  					=> 'Hubi Hantida',
    'checkout'  				=> 'Hubi Hantida',
    'clone'  					=> 'Hantida Clone',
    'deployable'  				=> 'La geyn karo',
    'deleted'  					=> 'Hantidan waa la tirtiray.',
    'delete_confirm'            => 'Ma hubtaa inaad doonayso inaad tirtirto hantidan?',
    'edit'  					=> 'Wax ka beddel hantida',
    'model_deleted'  			=> 'Qaabkan Hantida waa la tirtiray Waa inaad soo celisaa qaabka ka hor inta aanad soo celin Hantida.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'La codsan karo',
    'requested'				    => 'La codsaday',
    'not_requestable'           => 'Looma baahna',
    'requestable_status_warning' => 'Ha bedelin heerka la codsan karo',
    'restore'  					=> 'Soo Celinta Hantida',
    'pending'  					=> 'La sugayo',
    'undeployable'  			=> 'Aan la hawlgelin',
    'undeployable_tooltip'  	=> 'Hantidani waxay leedahay calaamad xaaladeed oo aan la hawlgelin oo aan la hubin karin wakhtigan.',
    'view'  					=> 'Daawo Hantida',
    'csv_error' => 'Khalad baad ku leedahay faylkaaga CSV:',
    'import_text' => 'Soo rar CSV oo ka kooban taariikhda hantida Hantida iyo isticmaalayaashu waa inay hore ugu jiraan nidaamka, ama waa laga boodi doonaa. Hantida ku habboon soo dejinta taariikhda waxay ku dhacdaa calaamadda hantida Waxaan isku dayi doonaa inaan helno isticmaale u dhigma iyadoo lagu salaynayo magaca isticmaalaha aad bixisay, iyo shuruudaha aad hoos ku doorato. Haddii aadan hoos dooran wax shuruud ah, waxay si fudud isku dayi doontaa inay ku habboonaato qaabka isticmaale ee aad ku habaysay <code>Admin &gt; Goobaha Guud</p><p>Meelaha ku jira CSV-ga waa in ay iswaafaqaan madaxyada: <strong>Hanti Tag, Magaca, Taariikhda hubinta, Taariikhda hubinta</strong>. Goob kasta oo dheeri ah waa la iska indhatiraa </p><p>Taariikhda jeegeynta: taariikhaha jeegeynta banaan ama mustaqbalka waxay hubin doontaa alaabta isticmaalaha. Marka laga reebo tiirka Taariikhda Jeegaynta waxay abuuri doontaa taariikh hubin leh taariikhda maanta.</p>    ',
    'csv_import_match_f-l' => 'Isku day inaad isticmaalayaasha ku wajahdo qaabka<strong>firstname.name</strong>(<code>jane.smith</code>)',
    'csv_import_match_initial_last' => 'Isku day inaad isticmaalayaasha ku wajahdo qaabka<strong>firstname. name</strong>(<code>jane. smith</code>)',
    'csv_import_match_first' => 'Isku day inaad isticmaalayaasha ku wajahdo qaabka <strong>firstname. name</strong>(<code>jane. smith</code>) format',
    'csv_import_match_email' => 'Isku day inaad isticmaalayaasha ku waafajiso<strong>email</strong> sidii isticmaale ahaan',
    'csv_import_match_username' => 'Isku day inaad isticmaalayaasha ku waafajiso<strong>username</strong>',
    'error_messages' => 'Fariimaha khaldan:',
    'success_messages' => 'Farriimaha guusha:',
    'alert_details' => 'Fadlan hoos ka eeg faahfaahinta.',
    'custom_export' => 'Dhoofinta gaarka ah',
    'mfg_warranty_lookup' => ':manufacturer Raadinta Xaaladda damaanada',
    'user_department' => 'Waaxda Isticmaalaha',
];

==> snipe-it-8.0.1.zip: snipe-it-8.0.1/resources/lang/so-SO/admin/hardware/general.php <==
<?php

return [
    'about_assets_title'           => 'Ku saabsan Hantida',
    'about_assets_text'            => 'Hantidu waa shay lagu raadraaco lambar taxane ah ama sumad hanti ah. Waxay u muuqdaan inay yihiin shay qiimo sare leh marka la aqoonsanayo shay gaar ah.',
    'archived'  				=> 'Kaydsan',
    'asset'  					=> 'Hantida',
    'bulk_checkout'             => 'Hubinta Buuxda',
    'bulk_checkin'              => 'Bulk Checkin',
    'checkin'  					=> 'Hubi Hantida',
    'checkout'  				=> 'Hubi Hantida',
    'clone'  					=> 'Hantida Clone',
    'deployable'  				=> 'La geyn karo',
    'deleted'  					=> 'Hantidan waa la tirtiray.',
    'delete_confirm'            => 'Ma hubtaa inaad doonayso inaad tirtirto hantidan?',
    'edit'  					=> 'Wax ka beddel hantida',
    'model_deleted'  			=> 'Qaabkan Hantida waa la tirtiray Waa inaad soo celisaa qaabka ka hor inta aanad soo celin Hantida.',
    'model_invalid'             => 'This model for this asset is invalid.',
    'model_invalid_fix'         => 'The asset must be updated use a valid asset model before attempting to check it in or out, or to audit it.',
    'requestable'               => 'La codsan karo',
    'requested'				    => 'La codsaday',
    'not_requestable'           => 'Looma baahna',
    'requestable_status_warning' => 'Ha bedelin heerka la codsan karo',
    'restore'  					=> 'Soo Celinta Hantida',
    'pending'  					=> 'La sugayo',
    'undeployable'  			=> 'Aan la hawlgelin',
    'undeployable_tooltip'  	=> 'Hantidani waxay leedahay calaamad xaaladeed oo aan la hawlgelin oo aan la hubin karin wakhtigan.',
    'view'  					=> 'Daawo Hantida',
    'csv_error' => 'Khalad baad ku leedahay faylkaaga CSV:',
    'import_text' => 'Soo rar CSV oo ka kooban taariikhda hantida Hantida iyo isticmaalayaashu waa inay hore ugu jiraan nidaamka, ama waa laga boodi doonaa. Hantida ku habboon soo dejinta taariikhda waxay ku dhacdaa calaamadda hantida Waxaan isku dayi doonaa inaan helno isticmaale u dhigma iyadoo lagu salaynayo magaca isticmaalaha aad bixisay, iyo shuruudaha aad hoos ku doorato. Haddii aadan hoos dooran wax shuruud ah, waxay si fudud isku dayi doontaa inay ku habboonaato qaabka isticmaale ee aad ku habaysay <code>Admin &gt; Goobaha Guud</p><p>Meelaha ku jira CSV-ga waa in ay iswaafaqaan madaxyada: <strong>Hanti Tag, Magaca, Taariikhda hubinta, Taariikhda hubinta</strong>. Goob kasta oo dheeri ah waa la iska indhatiraa </p><p>Taariikhda jeegeynta: taariikhaha jeegeynta banaan ama mustaqbalka waxay hubin doontaa alaabta isticmaalaha. Marka laga reebo tiirka Taariikhda Jeegaynta waxay abuuri doontaa taariikh hubin leh taariikhda maanta.</p>    ',
    'csv_import_match_f-l' => 'Isku day inaad isticmaalayaasha ku wajahdo qaabka<strong>firstname.name</strong>(<code>jane.smith</code>)',
    'csv_import_match_initial_last' => 'Isku day inaad isticmaalayaasha ku wajahdo qaabka<strong>firstname. name</strong>(<code>jane. smith</code>)',
    'csv_import_match_first' => 'Isku day inaad isticmaalayaasha ku wajahdo qaabka <strong>firstname. name</strong>(<code>jane. smith</code>) format',
    'csv_import_match_email' => 'Isku day inaad isticmaalayaasha ku waafajiso<strong>email</strong> sidii isticmaale ahaan',
    'csv_import_match_username' => 'Isku day inaad isticmaalayaasha ku waafajiso<strong>username</strong>',
    'error_messages' => 'Fariimaha khaldan:',
    'success_messages' => 'Farriimaha guusha:',
    'alert_details' => 'Fadlan hoos ka eeg faahfaahinta.',
    'custom_export' => 'Dhoofinta gaarka ah',
    'mfg_warranty_lookup' => ':manufacturer Raadinta Xaaladda damaanada',
    'user_department' => 'Waaxda Isticmaalaha',
];
